Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
TLRC(1) 			   tlrc manual				 TLRC(1)

NAME
     tlrc - official tldr client written in Rust

SYNOPSIS
     tldr [options] [page]...

DESCRIPTION
     If  the page argument is provided (with no other operations), tlrc displays
     the tldr page entitled page. If multiple arguments are provided,  they  are
     concatenated  with hyphens between each argument (e.g. git checkout becomes
     git-checkout). Page names are  case  insensitive.	If  multiple  pages  are
     found,  a	warning  is  shown and the page from the preferred platform (see
     --platform) is displayed. If the page only exists	in  other  platforms,  a
     warning  is shown and the page from the first platform (in alphabetical or-
     der) is displayed.
     For other operations, see OPTIONS.

     Pages are loaded from a cache directory. If this directory is empty,  pages
     will  be  automatically downloaded when you run tldr. After that tlrc works
     completely offline until an automatic update is triggered (when  the  cache
     is  more  than  2	weeks old by default), or if an update is explicitly re-
     quested using --update.

OPTIONS
   Operations
     Only one of these options can be used at a time.

     -u, --update
	 Update the cache of tldr pages. This will first download the sha256sums
	 of all archives and compare them to the old  sums  to	determine  which
	 languages  need  updating.  If you want to force a redownload, run tldr
	 --clean-cache beforehand.

     -l, --list
	 List all English pages in the current platform,  one  per  line  (names
	 only).  The  special  platform common contains documentation for cross-
	 platform tools, and is always listed.

     -a, --list-all
	 List all English pages, one per line (names only).

     -s, --search <KEYWORD>
	 List pages containing a keyword, along with their  respective	language
	 and  platform.  All platforms are searched by default. If --platform is
	 specified, this behaves like --list (i.e. the	specified  platform  and
	 common are searched).

     --list-platforms
	 List available platforms.

     --list-languages
	 List  available languages. Use --info for a language list with more in-
	 formation.

     -i, --info
	 Show cache information (path, age, installed languages and  the  number
	 of pages).

     -r, --render <FILE>
	 Render the specified tldr page.

     --clean-cache
	 Interactively delete contents of the cache directory.
	 The tldr.sha256sums file is always removed to force a redownload of all
	 page archives during the next update. You can also choose to delete al-
	 ready downloaded languages.

     --gen-config
	 Print the default config to standard output.

     --config-path
	 Print	the  default  config  path and create the config directory if it
	 does not exist.

     -v, --version
	 Print version information.

     -h, --help
	 Print a help message.

   Other options
     These options modify the behavior of operations.

     -p, --platform <PLATFORM>
	 Specify the platform to use (linux, osx, windows, etc.).

	 Tldr pages are grouped by the operating system the  documented  command
	 runs  on.  If	a program can run on more than one operating system (and
	 behaves in the same way), the page for it is put into the special  com-
	 mon platform, which is always searched. Specifying --platform common is
	 allowed and causes common to be the only searched platform.

	 Default: the operating system you are currently running

     -L, --language <LANGUAGE_CODE>
	 Specify  the  language  to  show  pages in. Can be used multiple times.
	 Overrides all other language detection methods. tlrc will not fall back
	 to English when this option is used, and will instead	show  an  error.
	 Note that this option does not affect languages downloaded on --update.
	 If  you want to use languages not defined in environment variables, use
	 the cache.languages option in the config file.

	 Default: taken from the config or the	LANG  and  LANGUAGE  environment
	 variables. See
	 https://github.com/tldr-pages/tldr/blob/main/CLIENT-SPECIFICATION.md#language
	 for a detailed description of how tlrc determines the language.

     --short-options
	 In option placeholders, display short options wherever possible.
	 Example:  "{{[-s|--long]}}"  will  be displayed as "-s" when using this
	 option. Equivalent of setting output.option_style="short" in  the  con-
	 fig.

	 When  used with --long-options, the above placeholder will be displayed
	 as "[-s|--long]". Using both options  is  equivalent  to  setting  out-
	 put.option_style="both" in the config.

     --long-options
	 In option placeholders, display long options wherever possible.
	 Example:  "{{[-s|--long]}}"  will  be	displayed as "--long" when using
	 this option. Equivalent of setting  output.option_style="long"  in  the
	 config.

	 This is the default.

     --edit
	 Display  a link to edit the shown page on GitHub. Equivalent of setting
	 output.edit_link=true in the config.

	 The following link will be displayed:
	 https://github.com/tldr-pages/tldr/edit/main/{{pages|pages.lan-
	 guage}}/{{platform}}/{{page-name}}.md

     -o, --offline
	 Do not update the cache, even if it is stale and automatic updates  are
	 on.  Similar  to  setting cache.auto_update=false in the config, except
	 using this will show an error if the cache is empty.

     -c, --compact
	 Strip empty  lines  from  output.  Equivalent	of  setting  output.com-
	 pact=true in the config.

     --no-compact
	 Do not strip empty lines from output. Equivalent of setting output.com-
	 pact=false in the config. This always overrides --compact.

     -R, --raw
	 Print	pages  in  raw	markdown. Equivalent of setting output.raw_mark-
	 down=true in the config.

     --no-raw
	 Render pages instead of printing raw file contents. Equivalent of  set-
	 ting  output.raw_markdown=false  in  the  config. This always overrides
	 --raw.

     -q, --quiet
	 Suppress status messages and warnings. In other words, this makes  tlrc
	 print only pages and errors.

	 This always overrides --verbose.

     --verbose
	 Be more verbose, print debug information. Useful to see what exactly is
	 being done if you're having issues.

	 Can  be  specified  twice  for even more messages. Using --verbose more
	 than twice has no other effect.

     --color <WHEN>
	 Specify when to enable color.
	 Can be one of the following: 'always', 'never', 'auto'.
	 always forces colors on; never forces colors off; and auto  only  auto-
	 matically  enables  colors  when outputting onto a tty and the NO_COLOR
	 environment variable is not set or is an empty string.

	 Default: auto

     --config <FILE>
	 Specify an alternative path to the config file. This  option  overrides
	 all  config  detection  methods  (i.e.  OS-specific directories and the
	 $TLRC_CONFIG environment variable).

	 Default: platform-dependent (use --config-path to see the default  path
	 for your system)

CONFIGURATION
     To generate a default config file, run:

	    tldr --gen-config > "$(tldr --config-path)"

     See  https://github.com/tldr-pages/tlrc#configuration for an example config
     file with explanations.

     The default config path depends on your operating system:
     Linux and	BSD:  $XDG_CONFIG_HOME/tlrc/config.toml  or  ~/.config/tlrc/con-
     fig.toml if $XDG_CONFIG_HOME is unset
     macOS: ~/Library/Application Support/tlrc/config.toml
     Windows: %ROAMINGAPPDATA%\tlrc\config.toml

     No  matter the OS, you can set the $TLRC_CONFIG environment variable or use
     --config to override the default path. The command-line option takes prece-
     dence over all other detection methods.

EXAMPLES
     See the tldr page for tar:

	    tldr tar

     See the tldr page for diskpart, from platform windows:

	    tldr --platform windows diskpart

     Search for pages that contain the string tar:

	    tldr --search tar

EXIT STATUSES
     0	    OK

     1	    I/O and various other errors

     2	    Invalid command-line arguments

     3	    TOML (config file) parse error

     4	    Errors related to cache updates (e.g. a failed HTTP GET request)

     5	    Tldr syntax error (e.g. a non-empty line that does not start with '#
	    ', '> ', '- ' or '`')

AUTHOR
     Lena Pastwa <lena@lnps.me>

SEE ALSO
     tldr client specification
     https://github.com/tldr-pages/tldr/blob/main/CLIENT-SPECIFICATION.md

     tlrc repository (report issues with the client here)
     https://github.com/tldr-pages/tlrc

     tldr-pages repository (report issues with the pages here)
     https://github.com/tldr-pages/tldr

     An online version of this man page is available here:
     https://tldr.sh/tlrc

tlrc 1.13.1			   2026-05-22				 TLRC(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=tldr&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help